#
# spec file for package ghc-typst
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name typst
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.1
Release:        1.8
Summary:        Parsing and evaluating typst syntax
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-cassava-devel
BuildRequires:  ghc-cassava-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-ordered-containers-devel
BuildRequires:  ghc-ordered-containers-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-pretty-prof
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-regex-tdfa-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-scientific-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-toml-parser-devel
BuildRequires:  ghc-toml-parser-prof
BuildRequires:  ghc-typst-symbols-devel
BuildRequires:  ghc-typst-symbols-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-xml-conduit-prof
BuildRequires:  ghc-yaml-devel
BuildRequires:  ghc-yaml-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-pretty-show-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-golden-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
A library for parsing and evaluating typst syntax. Typst (<https://typst.app>)
is a document layout and formatting language. This library targets typst 0.10
and currently offers only partial support.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Dec  7 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.6.1.
  [#]# 0.6.1
  * Fix precedence for functions (#55).
    `1(x)` and `!(x)` should not be parsed as functions.
    Note that we still don't match typst's behavior for `f_"!"(x)`.
    For us this works just like `f_!(x)`, but for typst we get
    a function in the subscript for the former but not the latter.
    Fixing this would require some changes in the types.
  * Define sys.version and sys.inputs.typst-hs-version (#56).
    The former is set to the version of typst we are trying to
    implement. The latter is a stringified version number from typst-hs.
    This will allow typst programs to tell when they're running
    on typst-hs (or pandoc), and react accordingly.
  * Rename stBeforeSpace -> stSpaceBefore to avoid confusion.
  * Fix precedence issues in math parsing (#54).
    Increased precedence of ! (factorial).
    `_` or `^` should eagerly gobble a grouped argument (`c_(a)`).
  * Minimal support for `context` (#53). Parse `context` keyword.
    New Context constructor in Expr [API change].
    Evaluate this by just evaluating the expression, for now.
    Note that we don't support the features (like location or
    numbering) that context is used to affect anyway, so this change
    probably won't be enough for meaningful support. But it might
    prevent some documents from issuing errors.
  * Arguments at method.
  * Array windows, reduce, to-dict methods.
  * Allow parentheses in import.
  * Make standard module available under std (typst 0.12).
  * Add over/underparen, over/undershell in math module.
  * Add stretch function.
  * Add skew.
  * Depend on typst-symbols 0.1.7 and start to target typst 0.12.
  * Reset indentation requirements inside `[]` content block. e.g.
    ```
    / B: #block[
  - a
    ]
    ```
    We don't need indentation inside the block content.
* Tue Sep 10 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.6.
  [#]# 0.6
  * Recognize figure.caption function (#52).
  * Allow defined identifiers to override math defaults (#51).
    Previously we evaluated all math in a special environment that
    shadowed any user-defined functions with the same-named functions
    from the math or sym modules. This change gives user-defined identifiers
    priority over the math defaults, allowing things like `bb` to be
    overridden.
  * Typst.Types: EvalState now has two new fields, `evalMathIdentifiers` and
    `evalStandardIdentifiers`. `evalIdentifiers` is now just for user-defined
    identifiers. [API change]
  * Don't implicitly load sys module for math.
* Sun Jul 28 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.5.0.5.
  [#]# 0.5.0.5
  * Allow numbers like `1.` in math mode (#50).
* Mon Jun 24 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.5.0.4.
  [#]# 0.5.0.4
  * Add built-in identifiers for standard types (#21):
    array, bool, content, int, float, regex, length,
    alignment, color, symbol, string.
  * Adjust emphasis parser for CJK characters (#49).
    Typst documentation says that `*` strong emphasis
    "only works at word boundaries." However, in typst/typst#2648
    this was changed for CJK.
* Sun Apr  7 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.5.0.3.
  [#]# 0.5.0.3
  * Support grid.(cell,header,footer,hline,vline) (#44).
  * Support table.(cell,vline,hline,header,footer) (#44).
  * Allow space after equation in code (#43).
  * Treat unicode whitespace characters as whitespace (#43).
  * Allow raw (backticked) content as code expression (#43).
  * Allow colon in label (#43).
  * Allow line comments at end of file (#43).
  * Depend on typst-symbols 0.1.6.
  * Add Haddock docs to parts of the public API (Eli Adelhult,
    Leopold Wigratt).
  * Avoid backtracking in `pDictExpr` (Jonathan Widén).
  * Allow colon in dict literal (Jonathan Widén) (#43, #45).
* Thu Mar 14 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.5.0.2.
  [#]# 0.5.0.2
  * Fix parsing of field access in math (#41). `$plus.circle_2$`
    should give you a subscript 2 on the symbol `plus.circle`.
    Underscores are not allowed in field access in math.
  * Support toml-parser-2.0.0.0 (Eric Mertens).
* Wed Feb 14 2024 Peter Simons <psimons@suse.com>
- Update typst to version 0.5.0.1.
  [#]# 0.5.0.1
  * Set `evalPackageRoot` to working dir to start, even if the file to be
    converted is somewhere else. This seems to be what the test suite expects.
  * Make file loading relative to package root if present (#39).
  * Parser: remove `pBindExpr` from `pBaseExpr`. It does not seem
    to be necessary, and it causes problems with things like `$#x = $y$` (#34).
  * Fix assignment of module name in package imports (#30).
  * Don't allow `container.at` to insert new values (#26).
  * Handle `dict.at(variable) = expression` (#25).
  * Remove dependency on the unmaintained digits library (#24).
    We just copy the code for the function we need (with
    attribution): it is BSD3-licensed.
* Sat Dec 16 2023 Peter Simons <psimons@suse.com>
- Update typst to version 0.5.
  [#]# 0.5
  * Support "as" keyword in imports (#21).
    [API change] In Typst.Syntax, the Imports type now contains
    fields for an optional "as" identifier.
  * Support version type (#21).
    [API change] Add VVersion constructor to Val, TVersion to ValType.
    Support the `version` constructor function and the `at` method (#21).
  * Parser: Ensure that `set` rule doesn't pick up `if` on next line (#23).
  * Parser: Allow multiline strings (#20).
  * Allow function applications in dictionary key construction (#19).
    [API change]:  in Typst.Syntax, the Dict constructor for Expr
    now takes type `[Spreadable (Expr, Expr)]` instead of
    `[Spreadable (Identifier, Expr)]`. This is because the key
    identifiers sometimes are not known at parse time and must
    be computed in Evaluate.
  [#]# 0.4
  * `evaluateTypst` now returns a single Content instead of a sequence
    (breaking API change). The Content is a "document" element that wraps
    the other contents. (This is added automatically in typst:
    https://typst.app/docs/reference/model/document/#parameters-title.)
  * Improve math parser.
  * Add `sys` module and `sys.version`.
  * Math: add `sech` and `csch` operators, `math.mid`.
  * `math.op` is no longer limited to string argument.
  * Remove automatic matching for `|..|` in math (typst 0.8 breaking change).
  * Fix `in` so it works with a type.
  * `repr` label with angle brackets.
  * `cite` now just takes one positional element, a label
    instead of strings (typst 0.9 breaing change).
  * Add `quote` element.
  * Add first-class types. `type()` function now returns a
    ValType instead of a string. Allow ValTypes to == strings
    for compatibility, as in typst.
  * `highlight` element for text.
  * Allow array `zip` method to take any number of arguments.
  * Add `calc.tau`.
  * Add array `intersperse` method.
  * Add string `rev` method.
  * Fix search path for typst packages, from
    `cache/typst/packages/preview/packagename-major.minor.patch` to
    `cache/typst/packages/preview/packagename-major/minor.patch` (#18).
  * Add support of 'wide' spacing character.
  * Fix precedence for numerical attachments (#17).
    Typst makes a subtle distinction between `$a_1(x)$`, in which
    the `_` groups more tightly than the `(..)`, and $`a_f(x)$`,
    in which the `(..)` groups more tightly than the `_`.
    This patch implements the distinction.  This fixes conversion of,
    e.g., `$n(a)^(b)$`.
  * Use typst-symbols 0.1.5.
* Fri Oct 27 2023 Peter Simons <psimons@suse.com>
- Update typst to version 0.3.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/typst-0.3.2.1/src/CHANGELOG.md
* Wed Jun  7 2023 Peter Simons <psimons@suse.com>
- Add typst at version 0.1.0.0.
